@@ -5,8 +5,8 @@
 ;; Author: Ryan Yeske <rcyeske@vcn.bc.ca>
 ;; Maintainer: George Huebner <george@feyor.sh>
 ;; Created: Sat Mar 18 11:31:52 2000
-;; Package-Version: 20260202.54
-;; Package-Revision: c17e18049da8
+;; Package-Version: 20260210.119
+;; Package-Revision: dfd8b26bac48
 ;; Keywords: games
 ;; URL: https://github.com/Feyorsh/nethack-el
 
@@ -45,6 +45,7 @@
 (require 'nethack-lisprec)
 (require 'nethack-gen-tiles)
 
+(require 'cl-lib)
 (require 'url)
 (require 'dired-aux)
 (require 'face-remap)
@@ -53,22 +54,38 @@
   "Emacs Lisp frontend to the lisp window port of Nethack."
   :group 'games)
 
-(defconst nethack-el-version "0.15.0")
-(defconst nethack-el-earliest-compatible-version "0.13.0")
+(defconst nethack-el-version "0.15.1")
 (defun nethack-el-version ()
-  "Print version of nethack-el."
+  "Print version of nethack-el and patched Nethack."
+  ;; credit to magit-version from Jonas Bernoulli's magit
   (interactive)
-  (message "nethack-el %s" nethack-el-version))
-
-(defcustom nethack-status-window-height 4
-  "Height of the status window."
-  :type '(integer)
-  :group 'nethack)
-
-(defcustom nethack-message-window-height 10
-  "Height of the message window."
-  :type '(integer)
-  :group 'nethack)
+  (let ((nethack--el-version
+         (let ((nethack--el (or load-file-name buffer-file-name)))
+           (unless (and nethack--el
+                        (member (file-name-nondirectory nethack--el)
+                                '("nethack.el" "nethack.el.gz")))
+             (let ((load-suffixes (reverse load-suffixes)))
+               (setq nethack--el (locate-library "nethack"))))
+           (setq nethack--el (and nethack--el (file-chase-links nethack--el)))
+           (if nethack--el
+               (let* ((dir (file-name-directory nethack--el))
+                      (dirname (file-name-nondirectory (directory-file-name dir))))
+                 (if-let ((gitdir (expand-file-name ".git" dir))
+                          ((executable-find "git"))
+                          (default-directory (and (file-exists-p gitdir) dir)))
+                     (shell-command-to-string "git describe --tags --dirty --always")
+                   (or (and (string-match-p "nethack-\\([0-9]\\{8\\}\\.[0-9]\\{4\\}\\)" dirname)
+                            (match-string 1 dirname))
+                       (ignore-errors
+                         (require 'lisp-mnt)
+                         (with-temp-buffer
+                           (insert-file-contents
+                            (locate-library "nethack.el" t))
+                           (lm-header "Version")))
+                       nethack-el-version)))))))
+    (message "nethack-el %s, %s"
+             (string-trim-right nethack--el-version)
+             (or (car (nethack--get-version)) "could not determine NetHack version"))))
 
 (defcustom nethack-status-highlight-delay
   (if-let ((op (cdr-safe (nethack-options-set-p "statushilites"))))
@@ -459,7 +476,7 @@ See https://nethackwiki.com/wiki/Environment_variable for more information."
 
 (defcustom nethack-version
   "3.6.7"
-  "The NetHack version to download, install, and bulid."
+  "The NetHack version to download, install, and build."
   :group 'nethack
   :type 'string)
 
@@ -477,25 +494,34 @@ input a different version at their own peril."
   (interactive)
   (completing-read "NetHack version: " '("3.6.7" "3.7.0") nil nil))
 
+(defun nethack--get-version ()
+  "Determine the version of a patched NetHack if such a version is
+installed.  Checks whether a NetHack executable exists, and if running
+it results in an output with the expected form."
+  (when-let* ((version-string (and nethack-program
+                                   (file-executable-p nethack-program)
+                                   (shell-command-to-string
+                                    (concat nethack-program " --version"))))
+              (version-info (progn (string-match
+                                    (concat "NetHack Version "
+                                            "\\([0-9]+\\.[0-9]+\\.[0-9]+\\(?:-[0-9]+\\)?\\)"
+                                            " lisp-patch "
+                                            "\\([0-9]+\\.[0-9]+\\.[0-9]+\\)")
+                                    version-string)
+                                   (match-data))))
+    (let (ret)
+      (cl-loop
+            for (start end)
+            on version-info
+            by #'cddr
+            do (when (and start end) (push (substring-no-properties version-string start end) ret)))
+      (reverse ret))))
+
 (defun nethack-installed-p ()
-  "Determine if a patched NetHack is installed.
-Checks whether a NetHack executable exists, and if running it results
-in an output with prefix ``(nethack-nhapi-raw-print'' with the correct
-NetHack version and the correct version for the lisp-patch."
-  (and nethack-program
-       (file-executable-p nethack-program)
-       (let ((version-string
-              (shell-command-to-string
-               (concat nethack-program " --version"))))
-         (version<=
-          nethack-el-earliest-compatible-version
-          (and (string-match
-                (concat "NetHack Version "
-                        "[0-9]+\\.[0-9]+\\.[0-9]+\\(?:-[0-9]+\\)?"
-                        " lisp-patch "
-                        "\\([0-9]+\\.[0-9]+\\.[0-9]+\\)")
-                version-string)
-               (match-string-no-properties 1 version-string))))))
+  "Check whether a version of NetHack compatible with nethack-el is installed."
+  (version=
+   nethack-el-version
+   (nth 2 (nethack--get-version))))
 
 (defun nethack-build (&optional no-download-p)
   "Build the NetHack program in the background.
